@@ -16,9 +16,9 @@ use swc_estree_ast::{
     BindExpression, CallExpression, Callee, ClassExpression, ConditionalExpression, DoExpression,
     Expression, FunctionExpression, Identifier, Import, JSXAttrVal, JSXAttribute,
     JSXEmptyExpression, JSXExprContainerExpr, JSXExpressionContainer, JSXMemberExprObject,
-    JSXMemberExpression, JSXSpreadAttribute, LogicalExprOp, LogicalExpression, MemberExprProp,
-    MemberExpression, MetaProperty, ModuleExpression, NewExpression, ObjectExprProp,
-    ObjectExpression, ObjectKey, ObjectMethod, ObjectPropVal, ObjectProperty,
+    JSXMemberExpression, JSXSpreadAttribute, Literal, LogicalExprOp, LogicalExpression,
+    MemberExprProp, MemberExpression, MetaProperty, ModuleExpression, NewExpression,
+    ObjectExprProp, ObjectExpression, ObjectKey, ObjectMethod, ObjectPropVal, ObjectProperty,
     OptionalCallExpression, OptionalMemberExprProp, OptionalMemberExpression,
     ParenthesizedExpression, PatternLike, PipelinePrimaryTopicReference, RecordExpression,
     SequenceExpression, TSAsExpression, TSNonNullExpression, TSTypeAssertion,
@@ -41,11 +41,11 @@ impl Swcify for Expression {
             Expression::Conditional(e) => e.swcify(ctx).into(),
             Expression::Func(e) => e.swcify(ctx).into(),
             Expression::Id(e) => e.swcify(ctx).id.into(),
-            Expression::StringLiteral(e) => e.swcify(ctx).into(),
-            Expression::NumericLiteral(e) => e.swcify(ctx).into(),
-            Expression::NullLiteral(e) => Lit::from(e.swcify(ctx)).into(),
-            Expression::BooleanLiteral(e) => Lit::from(e.swcify(ctx)).into(),
-            Expression::RegExpLiteral(e) => Lit::from(e.swcify(ctx)).into(),
+            Expression::Literal(Literal::String(e)) => e.swcify(ctx).into(),
+            Expression::Literal(Literal::Numeric(e)) => e.swcify(ctx).into(),
+            Expression::Literal(Literal::Null(e)) => Lit::from(e.swcify(ctx)).into(),
+            Expression::Literal(Literal::Boolean(e)) => Lit::from(e.swcify(ctx)).into(),
+            Expression::Literal(Literal::RegExp(e)) => Lit::from(e.swcify(ctx)).into(),
             Expression::Logical(e) => e.swcify(ctx).into(),
             Expression::Member(e) => e.swcify(ctx).into(),
             Expression::New(e) => e.swcify(ctx).into(),
@@ -63,12 +63,12 @@ impl Swcify for Expression {
             Expression::TemplateLiteral(e) => e.swcify(ctx).into(),
             Expression::Yield(e) => e.swcify(ctx).into(),
             Expression::Await(e) => e.swcify(ctx).into(),
-            Expression::BigIntLiteral(e) => Expr::Lit(e.swcify(ctx).into()),
+            Expression::Literal(Literal::BigInt(e)) => Expr::Lit(e.swcify(ctx).into()),
             Expression::OptionalMember(e) => e.swcify(ctx).into(),
             Expression::OptionalCall(e) => e.swcify(ctx).into(),
             Expression::JSXElement(e) => Box::new(e.swcify(ctx)).into(),
             Expression::JSXFragment(e) => e.swcify(ctx).into(),
-            Expression::DecimalLiteral(e) => e.swcify(ctx).into(),
+            Expression::Literal(Literal::Decimal(e)) => e.swcify(ctx).into(),
             Expression::TSAs(e) => e.swcify(ctx).into(),
             Expression::TSTypeAssertion(e) => e.swcify(ctx).into(),
             Expression::TSNonNull(e) => e.swcify(ctx).into(),
